.. _core_classes:

Core library
~~~~~~~~~~~~

You can use some objects and actions in several application
deployments. All common parts are grouped into MuranoPL libraries.
Murano core library is a set of classes needed in every deployment as
helpers for application classes. This library is located under the
`meta <http://git.openstack.org/cgit/openstack/murano/tree/meta/io.murano/>`_
directory.
